@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -32,6 +32,9 @@ FAILEDOPERATION = 'FailedOperation'
 # 更新ACL失败
 FAILEDOPERATION_ACCESSCONTROLLIST = 'FailedOperation.AccessControlList'
 
+# 可用区资源包配额不足
+FAILEDOPERATION_CDCQUOTAINSUFFICIENT = 'FailedOperation.CdcQuotaInsufficient'
+
 # 关闭数据层失败，至少要保留热层和温层其中一层。
 FAILEDOPERATION_CLOSEDATATIER = 'FailedOperation.CloseDataTier'
 
@@ -422,6 +425,12 @@ LIMITEXCEEDED_PLUGININSTALL = 'LimitExceeded.PluginInstall'
 # 超出一个用户可以拥有的最大资源限制。
 LIMITEXCEEDED_RESOURCELIMIT = 'LimitExceeded.ResourceLimit'
 
+# 后端服务响应包大小超过配额限制
+LIMITEXCEEDED_RESPONSEPACKAGEOVERSIZE = 'LimitExceeded.ResponsePackageOversize'
+
+# 后端服务响应时间超过配额限制
+LIMITEXCEEDED_RESPONSETIMEOUT = 'LimitExceeded.ResponseTimeout'
+
 # 空间数超过配额。
 LIMITEXCEEDED_SPACECOUNT = 'LimitExceeded.SpaceCount'
 
@@ -605,6 +614,9 @@ UNSUPPORTEDOPERATION_INDEXSETTINGSREQUIRESET = 'UnsupportedOperation.IndexSettin
 # 不支持该操作，服务类型有误。
 UNSUPPORTEDOPERATION_INSTANCETYPEERROR = 'UnsupportedOperation.InstanceTypeError'
 
+# 当前ES集群版本过低，不支持Gpu机器
+UNSUPPORTEDOPERATION_KERNELNOTSUPPORTGPU = 'UnsupportedOperation.KernelNotSupportGpu'
+
 # 不支持该操作，license的类型有误。
 UNSUPPORTEDOPERATION_LICENSEERROR = 'UnsupportedOperation.LicenseError'
 
@@ -617,6 +629,9 @@ UNSUPPORTEDOPERATION_MIGRATE = 'UnsupportedOperation.Migrate'
 # 不支持多可用区变配。
 UNSUPPORTEDOPERATION_MULTIZONESUPGRADE = 'UnsupportedOperation.MultiZonesUpgrade'
 
+# 抱歉，您需要前往ES控制台购买页完成确认认证，我们才能为您提供所选的腾讯云服务。如果对于确认流程有任何疑问，可以联系我们：https://www.tencentcloud.com/zh/contact-us。
+UNSUPPORTEDOPERATION_NOTAGREEMENT = 'UnsupportedOperation.NotAgreement'
+
 # 用户同步日志的配置passLogstashId为空，不支持该操作。
 UNSUPPORTEDOPERATION_PASSLOGSTASHID = 'UnsupportedOperation.PassLogstashId'
 
