@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -113,6 +113,9 @@ FAILEDOPERATION_FREEZEBILLFAILED = 'FailedOperation.FreezeBillFailed'
 # 白名单免费配额不足。
 FAILEDOPERATION_INSUFFICIENTWHITELISTQUOTA = 'FailedOperation.InsufficientWhitelistQuota'
 
+# 暂无可用的鉴权token。
+FAILEDOPERATION_INVALIDAUTHTOKEN = 'FailedOperation.InvalidAuthToken'
+
 # 操作失败，用户类型异常。
 FAILEDOPERATION_INVALIDUSERTYPE = 'FailedOperation.InvalidUserType'
 
@@ -170,6 +173,9 @@ FAILEDOPERATION_RELEASESSHPORTFAILED = 'FailedOperation.ReleaseSSHPortFailed'
 # 存储库有绑定的实例，请先删除绑定的实例。
 FAILEDOPERATION_REPOBINDBYINSTANCE = 'FailedOperation.RepoBindByInstance'
 
+# 查询第三方机房信息失败
+FAILEDOPERATION_SERVERROOMQUERYFAILED = 'FailedOperation.ServerRoomQueryFailed'
+
 # 停止实例失败。
 FAILEDOPERATION_STOPJOBINSTANCEFAILED = 'FailedOperation.StopJobInstanceFailed'
 
